| Title: | Model-Based Dose-Escalation Trials |
|---|---|
| Description: | User-friendly Shiny apps for designing and evaluating phase I cancer clinical trials, with the aim to estimate the maximum tolerated dose (MTD) of a novel drug, using a Bayesian decision procedure based on logistic regression. |
| Authors: | Philip Pallmann [aut, cre], Fang Wan [aut] |
| Maintainer: | Philip Pallmann <[email protected]> |
| License: | GPL-2 |
| Version: | 0.3-1 |
| Built: | 2026-05-16 07:50:14 UTC |
| Source: | https://github.com/philippallmann/modest |
A user-friendly tool to design and evaluate phase I cancer clinical trials, with the aim to estimate the maximum tolerated dose (MTD) of a novel drug. This is a point-and-click implementation of the dose-escalation study design proposed by Zhou & Whitehead (2003) that uses a Bayesian logistic regression method. The graphical user interfaces (GUIs) are based on R's Shiny system.
design() conduct()design() conduct()
This package contains two separate modules:
1) The design module allows to investigate different design options and parameters, and to simulate their operating characteristics under various scenarios. Type design() and the GUI will open in a browser window.
2) The conduct module provides guidance for dose selection throughout the study, and a recommendation for the MTD at the end. Type conduct() and the GUI will open in a browser window.
Both modules generate a variety of graphs to visualise data and design properties, and create downloadable PDF reports of simulation results and study data analyses.
Philip Pallmann ([email protected])
Zhou Y, Whitehead J (2003) Practical implementation of Bayesian dose-escalation procedures. Drug Information Journal, 37(1), 45–59.
design() conduct()design() conduct()